==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/RootCauseAnalysisDetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOWNTIMEHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOWNTIMECOSTVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOTALCOST" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOSTPRODUCTIVITYHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PROBLEMDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WHATHAPPENED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WHY1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WHY2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WHY3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WHY4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WHY5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SOLUTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "downtimehours",
    "downtimecostvalue",
    "totalcost",
    "lostproductivityhours",
    "problemdescription",
    "whathappened",
    "why1",
    "why2",
    "why3",
    "why4",
    "why5",
    "solution"
})
@XmlRootElement(name = "RootCauseAnalysisDetails")
public class RootCauseAnalysisDetails {

    @XmlElement(name = "DOWNTIMEHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY downtimehours;
    @XmlElement(name = "DOWNTIMECOSTVALUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT downtimecostvalue;
    @XmlElement(name = "TOTALCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT totalcost;
    @XmlElement(name = "LOSTPRODUCTIVITYHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY lostproductivityhours;
    @XmlElement(name = "PROBLEMDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String problemdescription;
    @XmlElement(name = "WHATHAPPENED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String whathappened;
    @XmlElement(name = "WHY1", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why1;
    @XmlElement(name = "WHY2", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why2;
    @XmlElement(name = "WHY3", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why3;
    @XmlElement(name = "WHY4", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why4;
    @XmlElement(name = "WHY5", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why5;
    @XmlElement(name = "SOLUTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String solution;

    /**
     * Gets the value of the downtimehours property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDOWNTIMEHOURS() {
        return downtimehours;
    }

    /**
     * Sets the value of the downtimehours property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDOWNTIMEHOURS(QUANTITY value) {
        this.downtimehours = value;
    }

    /**
     * Gets the value of the downtimecostvalue property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getDOWNTIMECOSTVALUE() {
        return downtimecostvalue;
    }

    /**
     * Sets the value of the downtimecostvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setDOWNTIMECOSTVALUE(AMOUNT value) {
        this.downtimecostvalue = value;
    }

    /**
     * Gets the value of the totalcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTOTALCOST() {
        return totalcost;
    }

    /**
     * Sets the value of the totalcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTOTALCOST(AMOUNT value) {
        this.totalcost = value;
    }

    /**
     * Gets the value of the lostproductivityhours property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLOSTPRODUCTIVITYHOURS() {
        return lostproductivityhours;
    }

    /**
     * Sets the value of the lostproductivityhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLOSTPRODUCTIVITYHOURS(QUANTITY value) {
        this.lostproductivityhours = value;
    }

    /**
     * Gets the value of the problemdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROBLEMDESCRIPTION() {
        return problemdescription;
    }

    /**
     * Sets the value of the problemdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROBLEMDESCRIPTION(String value) {
        this.problemdescription = value;
    }

    /**
     * Gets the value of the whathappened property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHATHAPPENED() {
        return whathappened;
    }

    /**
     * Sets the value of the whathappened property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHATHAPPENED(String value) {
        this.whathappened = value;
    }

    /**
     * Gets the value of the why1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY1() {
        return why1;
    }

    /**
     * Sets the value of the why1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY1(String value) {
        this.why1 = value;
    }

    /**
     * Gets the value of the why2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY2() {
        return why2;
    }

    /**
     * Sets the value of the why2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY2(String value) {
        this.why2 = value;
    }

    /**
     * Gets the value of the why3 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY3() {
        return why3;
    }

    /**
     * Sets the value of the why3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY3(String value) {
        this.why3 = value;
    }

    /**
     * Gets the value of the why4 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY4() {
        return why4;
    }

    /**
     * Sets the value of the why4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY4(String value) {
        this.why4 = value;
    }

    /**
     * Gets the value of the why5 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY5() {
        return why5;
    }

    /**
     * Sets the value of the why5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY5(String value) {
        this.why5 = value;
    }

    /**
     * Gets the value of the solution property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOLUTION() {
        return solution;
    }

    /**
     * Sets the value of the solution property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOLUTION(String value) {
        this.solution = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/RootCauseAnalysisDetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DOWNTIMEHOURS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DOWNTIMECOSTVALUE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOTALCOST" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOSTPRODUCTIVITYHOURS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PROBLEMDESCRIPTION" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WHATHAPPENED" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WHY1" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WHY2" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WHY3" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WHY4" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WHY5" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SOLUTION" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "downtimehours",
    "downtimecostvalue",
    "totalcost",
    "lostproductivityhours",
    "problemdescription",
    "whathappened",
    "why1",
    "why2",
    "why3",
    "why4",
    "why5",
    "solution"
})
@XmlRootElement(name = "RootCauseAnalysisDetails")
public class RootCauseAnalysisDetails {

    @XmlElement(name = "DOWNTIMEHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY downtimehours;
    @XmlElement(name = "DOWNTIMECOSTVALUE", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT downtimecostvalue;
    @XmlElement(name = "TOTALCOST", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT totalcost;
    @XmlElement(name = "LOSTPRODUCTIVITYHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY lostproductivityhours;
    @XmlElement(name = "PROBLEMDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String problemdescription;
    @XmlElement(name = "WHATHAPPENED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String whathappened;
    @XmlElement(name = "WHY1", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why1;
    @XmlElement(name = "WHY2", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why2;
    @XmlElement(name = "WHY3", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why3;
    @XmlElement(name = "WHY4", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why4;
    @XmlElement(name = "WHY5", namespace = "http://schemas.datastream.net/MP_fields")
    protected String why5;
    @XmlElement(name = "SOLUTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String solution;

    /**
     * Gets the value of the downtimehours property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDOWNTIMEHOURS() {
        return downtimehours;
    }

    /**
     * Sets the value of the downtimehours property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDOWNTIMEHOURS(QUANTITY value) {
        this.downtimehours = value;
    }

    /**
     * Gets the value of the downtimecostvalue property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getDOWNTIMECOSTVALUE() {
        return downtimecostvalue;
    }

    /**
     * Sets the value of the downtimecostvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setDOWNTIMECOSTVALUE(AMOUNT value) {
        this.downtimecostvalue = value;
    }

    /**
     * Gets the value of the totalcost property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTOTALCOST() {
        return totalcost;
    }

    /**
     * Sets the value of the totalcost property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTOTALCOST(AMOUNT value) {
        this.totalcost = value;
    }

    /**
     * Gets the value of the lostproductivityhours property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getLOSTPRODUCTIVITYHOURS() {
        return lostproductivityhours;
    }

    /**
     * Sets the value of the lostproductivityhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setLOSTPRODUCTIVITYHOURS(QUANTITY value) {
        this.lostproductivityhours = value;
    }

    /**
     * Gets the value of the problemdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROBLEMDESCRIPTION() {
        return problemdescription;
    }

    /**
     * Sets the value of the problemdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROBLEMDESCRIPTION(String value) {
        this.problemdescription = value;
    }

    /**
     * Gets the value of the whathappened property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHATHAPPENED() {
        return whathappened;
    }

    /**
     * Sets the value of the whathappened property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHATHAPPENED(String value) {
        this.whathappened = value;
    }

    /**
     * Gets the value of the why1 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY1() {
        return why1;
    }

    /**
     * Sets the value of the why1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY1(String value) {
        this.why1 = value;
    }

    /**
     * Gets the value of the why2 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY2() {
        return why2;
    }

    /**
     * Sets the value of the why2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY2(String value) {
        this.why2 = value;
    }

    /**
     * Gets the value of the why3 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY3() {
        return why3;
    }

    /**
     * Sets the value of the why3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY3(String value) {
        this.why3 = value;
    }

    /**
     * Gets the value of the why4 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY4() {
        return why4;
    }

    /**
     * Sets the value of the why4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY4(String value) {
        this.why4 = value;
    }

    /**
     * Gets the value of the why5 property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWHY5() {
        return why5;
    }

    /**
     * Sets the value of the why5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWHY5(String value) {
        this.why5 = value;
    }

    /**
     * Gets the value of the solution property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSOLUTION() {
        return solution;
    }

    /**
     * Sets the value of the solution property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSOLUTION(String value) {
        this.solution = value;
    }

}
